# Private Message NodeJS

Instant updates and notifications for the [Private Message module](https://www.drupal.org/project/private_message)
module without the need for polling.

This listens for private message thread updates and uses the [drupal nodejs module](https://www.drupal.org/project/nodejs)
to trigger updates to the UI and provide notifications for members of the changed thread.

## How it works

By default, the private message module uses 'polling' to check for updates. This
means it sends a request to the server every X seconds to check if there are any
new messages. This can add a lot of additional overhead to the server,
particularly when the user leaves the private message page open and isn't even
looking at it. The alternative is to set the ajax refresh time to zero, which
disables updates altogether, requiring a page refresh to see if there are any
updates.
This module provides a solution that updates private message threads without the
use of polling,by integration with Nodejs, which handles updates in realtime.

## Benefits of this module

* No ajax polling means less work for the browser.
* No ajax polling means less work for the server.
* Message threads immediately show new messages

## Requirements

* [Private Message module](https://www.drupal.org/project/private_message)
* [Node.js](https://nodejs.org/)


## Installation

### 1. Install Node.js

Instructions on Node.js installation are not provided here, as they differ per
system, and instructions are outside the scope of this document. Please see
the [Node.js homepage](https://nodejs.org/en/) for more information.

### 2. Install the module

Install the private_message_nodejs module as you would any Drupal module.

### 3. Install the nodeJS dependendencies

On the command line, navigate to [PRIVATE_MESSAGE_MODULE_ROOT]/modules/private_message_nodejs/nodejs and run the
following command:

`npm install`

### 4. Confirm the Nodejs server is working

On the command line, navigate to [PRIVATE_MESSAGE_MODULE_ROOT]/modules/private_message_nodejs/nodejs and run the
following command:

`node app.js`

Note: Leave this open and running, as closing the server will stop it from
working.

### 5. Enter the URL to the node.js server in the private message configuration

In the web browser, navigate to /admin/config/private_message/config. Expand the
Private Message Nodejs settings section, and enter the URL to the node JS app.
It should be found at [your domain]:8080. Save.

### 6. Test

Open up the private message page and check that there has been some output in
the command line, indicating that connections have been made to the Nodejs
server.


## Authors

The Private Message Nodejs module was first written by
[Jeremy Graham](http://jez.me), integrating with the Drupal Node.js module.
A custom implementation that does not depend on that module was then written
by [Jay Friendly](https://www.jaypan.com).
