/**
 * @file
 * Client-side script to integrate the private message inbox block with Node.js.
 */

/*global jQuery, Drupal, drupalSettings, io*/
/*jslint white:true, this, browser:true*/

(function ($, Drupal, drupalSettings, io) {

  "use strict";

  var initialized, inboxSocket;

  function init() {

    // Only initialize once.
    if (!initialized) {
      initialized = true;

      inboxSocket = io(drupalSettings.privateMessageNodejs.nodejsUrl + "/pm_inbox");

      // Listen for a connection to the remote server.
      inboxSocket.on('connect', function () {
         // Enter the room for this user.
         inboxSocket.emit('user', drupalSettings.user.uid);
      });

      // Listen for an emission informing of thread update for a thread the user
      // belongs to.
      inboxSocket.on("update pm inbox", function () {
        // Fetch new messages from the server.
        Drupal.PrivateMessageInbox.updateInbox();
      });

      Drupal.AjaxCommands.prototype.privateMessageNodejsTriggerInboxUpdateCommand = function (ajax, response) {

        // For jSlint compatibility.
        ajax = ajax;

        if (Drupal.PrivateMessageInbox) {
          $.each(response.uids, function (index) {
            inboxSocket.emit("update pm inbox", response.uids[index]);
          });
        }
      };
    }
  }

  Drupal.behaviors.privateMessageNodejsInbox = {
    attach: function () {
      init();
    }
  };

}(jQuery, Drupal, drupalSettings, io));
