<?php

namespace Drupal\private_message_nodejs\Service;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Utility\Token;
use Drupal\private_message\Entity\PrivateMessageInterface;
use Drupal\private_message\Entity\PrivateMessageThreadInterface;

/**
 * Provides services for the PrivateMessageNodejs module.
 */
class PrivateMessageNodejsService implements PrivateMessageNodejsServiceInterface {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The token service.
   *
   * @var \Drupal\Core\Utility\Token
   */
  protected $token;

  /**
   * Constructs a PrivateMessageNodejsService object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The configuration factory.
   * @param \Drupal\Core\Utility\Token $token
   *   The token service.
   */
  public function __construct(
    ConfigFactoryInterface $configFactory,
    Token $token
  ) {
    $this->configFactory = $configFactory;
    $this->token = $token;
  }

  /**
   * {@inheritdoc}
   */
  public function buildBrowserPushNotificationData(
    PrivateMessageInterface $privateMessage,
    PrivateMessageThreadInterface $privateMessageThread
  ) {
    $config = $this->configFactory->get('private_message_nodejs.settings');

    $data = [
      'private_message' => $privateMessage,
      'private_message_thread' => $privateMessageThread,
    ];

    $message = [];

    $message['title'] = $this->token->replace(
      $config->get('browser_notification_title'),
      $data
    );

    $message['body'] = $this->token->replace(
      $config->get('browser_notification_body'),
      $data
    );

    $icon = $config->get('browser_notification_icon');
    if (!empty($icon)) {
      $message['icon'] = file_create_url(
        $this->token->replace(
          $icon,
          $data
        )
      );
    }

    $link = $config->get('browser_notification_link');
    if (!empty($link)) {
      $message['link'] = $this->token->replace(
        $link,
        $data
      );
    }

    return $message;
  }

}
